==> oval-interpreter_5.3.orig.tar.gz: oval-interpreter-5.3/src/AbsFunctionComponent.cpp <==
//
// $Id: AbsFunctionComponent.cpp 3659 2007-01-09 17:43:02Z bakerj $
//
//****************************************************************************************//
// Copyright (c) 2002-2007, The MITRE Corporation
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without modification, are
// permitted provided that the following conditions are met:
//
//     * Redistributions of source code must retain the above copyright notice, this list
//       of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice, this 
//       list of conditions and the following disclaimer in the documentation and/or other
//       materials provided with the distribution.
//     * Neither the name of The MITRE Corporation nor the names of its contributors may be
//       used to endorse or promote products derived from this software without specific 
//       prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
// SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
// OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
// TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
// EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
//****************************************************************************************//

#include "AbsFunctionComponent.h"

//****************************************************************************************//
//								AbsFunctionComponent Class								  //	
//****************************************************************************************//
AbsFunctionComponent::AbsFunctionComponent() : AbsComponent() {
	// -----------------------------------------------------------------------
	//	Abstract
	//
	//	Create a compelete AbsFunctionComponent object
	//
	// -----------------------------------------------------------------------

}

AbsFunctionComponent::~AbsFunctionComponent() {
	// -----------------------------------------------------------------------
	//	Abstract
	//
	//	Do nothing for now
	//
	// -----------------------------------------------------------------------
}

// ***************************************************************************************	//
//								 Public members												//
// ***************************************************************************************	//
AbsComponentVector* AbsFunctionComponent::GetComponents() {
	// -----------------------------------------------------------------------
	//	Abstract
	//
	//	Return the components field's value
	//
	// -----------------------------------------------------------------------

	return &this->components;
}

void AbsFunctionComponent::SetComponents(AbsComponentVector* components) {
	// -----------------------------------------------------------------------
	//	Abstract
	//
	//	Set the components field's value
	//
	// -----------------------------------------------------------------------

	this->components = (*components);
}

void AbsFunctionComponent::AppendComponent(AbsComponent* component) {
	// -----------------------------------------------------------------------
	//	Abstract
	//
	//	Set the components field's value
	//
	// -----------------------------------------------------------------------

	this->GetComponents()->push_back(component);
}

==> oval-interpreter_5.4.2.orig.tar.gz: oval-interpreter-5.4.2.orig/src/AbsFunctionComponent.cpp <==
//
// $Id: AbsFunctionComponent.cpp 4579 2008-01-02 17:39:07Z bakerj $
//
//****************************************************************************************//
// Copyright (c) 2002-2008, The MITRE Corporation
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without modification, are
// permitted provided that the following conditions are met:
//
//     * Redistributions of source code must retain the above copyright notice, this list
//       of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice, this 
//       list of conditions and the following disclaimer in the documentation and/or other
//       materials provided with the distribution.
//     * Neither the name of The MITRE Corporation nor the names of its contributors may be
//       used to endorse or promote products derived from this software without specific 
//       prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
// OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
// SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
// OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
// TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
// EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
//****************************************************************************************//

#include "AbsFunctionComponent.h"

//****************************************************************************************//
//								AbsFunctionComponent Class								  //	
//****************************************************************************************//
AbsFunctionComponent::AbsFunctionComponent() : AbsComponent() {
	// -----------------------------------------------------------------------
	//	Abstract
	//
	//	Create a complete AbsFunctionComponent object
	//
	// -----------------------------------------------------------------------

}

AbsFunctionComponent::~AbsFunctionComponent() {
	// -----------------------------------------------------------------------
	//	Abstract
	//
	//	Do nothing for now
	//
	// -----------------------------------------------------------------------
}

// ***************************************************************************************	//
//								 Public members												//
// ***************************************************************************************	//
AbsComponentVector* AbsFunctionComponent::GetComponents() {
	// -----------------------------------------------------------------------
	//	Abstract
	//
	//	Return the components field's value
	//
	// -----------------------------------------------------------------------

	return &this->components;
}

void AbsFunctionComponent::SetComponents(AbsComponentVector* components) {
	// -----------------------------------------------------------------------
	//	Abstract
	//
	//	Set the components field's value
	//
	// -----------------------------------------------------------------------

	this->components = (*components);
}

void AbsFunctionComponent::AppendComponent(AbsComponent* component) {
	// -----------------------------------------------------------------------
	//	Abstract
	//
	//	Set the components field's value
	//
	// -----------------------------------------------------------------------

	this->GetComponents()->push_back(component);
}
